@@ -1,5 +1,5 @@
 from pydantic.dataclasses import dataclass
-from .location import Location
+from travelperk_python_api_types.trips.location import Location
 
 
 @dataclass
