@@ -10,6 +10,6 @@ class Webhook:
     secret: str
     enabled: bool
     events: List[str]
-    successfully_sent: int
-    failed_sent: int
-    error_rate: float
+    successfully_sent: int = None
+    failed_sent: int = None
+    error_rate: float = None
